<?php

namespace App\Factory;

use App\Exception;

class StoreFactory {
    
    private $connection;
    
    public function __construct (\Doctrine\DBAL\Connection $connection) {
        $this->connection = $connection;
    }
    
    public function getStandardVendor ($branch) {
        $sql = "
            SELECT CDVENDEDOR
              FROM PARAVEND
             WHERE CDFILIAL = :CDFILIAL";
            
        $params = [
            ":CDFILIAL" => $branch    
        ];
        
        $vendor = $this->connection->fetchAll($sql, $params);
        
        if (empty($vendor)) 
            throw new Exception\ParamsException("Vendedor padrão não encontrado para a filial - $branch");
        
        if (!isset($vendor[0]["CDVENDEDOR"])) 
            throw new Exception\ParamsException("Vendedor padrão não encontrado para a filial - $branch");
        
        return $vendor[0]["CDVENDEDOR"];
    }
    
    public function getStandardStore ($branch, $vendor) {
        $sql = "
            SELECT C.CDCAIXA, C.CDLOJA , V.CDOPERADOR, L.NRMESAPADRAO AS NRMESA,
              L.IDPOSOBSPED , L.IDLUGARMESA
            FROM CAIXA C , VENDEDOR V, LOJA L
            WHERE C.CDCAIXA    = V.CDCAIXA
              AND C.CDFILIAL   = :CDFILIAL
              AND V.CDVENDEDOR = :CDVENDEDOR
              AND C.CDLOJA     = L.CDLOJA
              AND C.CDFILIAL   = L.CDFILIAL";
            
        $params = [
            ":CDFILIAL"   => $branch,
            ":CDVENDEDOR" => $vendor
        ];
        
        $store = $this->connection->fetchAll($sql, $params);
        
        //rever esse trecho
        if (empty($store)) 
            throw new Exception\ParamsException("Loja padrão não encontrada para a filial - $branch");
        
        if (!isset($store[0]["CDLOJA"])) 
            throw new Exception\ParamsException("Loja padrão não encontrada para a filial - $branch");
        
        return $store[0]["CDLOJA"];
    }
    
    public function getStandardCashier ($branch, $vendor) {
        $sql = "
            SELECT CDCAIXA, CDOPERADOR
              FROM VENDEDOR
            WHERE CDFILIAL   = :CDFILIAL
              AND CDVENDEDOR = :CDVENDEDOR";
            
        $params = [
            ":CDFILIAL"   => $branch,
            ":CDVENDEDOR" => $vendor
        ];
        
        $cashier = $this->connection->fetchAll($sql, $params);
        
        if (empty($cashier)) 
            throw new Exception\ParamsException("Caixa padrão não encontrado para a filial - $branch");
        
        if (!isset($cashier[0]["CDCAIXA"])) 
            throw new Exception\ParamsException("Caixa padrão não encontrado para a filial - $branch");
        
        return $cashier[0];
    }
    
    public function getProductControlId ($branch, $store) {
        $sql = "
            SELECT IDCONTROPROD
              FROM LOJA
             WHERE CDFILIAL = :CDFILIAL
               AND CDLOJA = :CDLOJA";
              
        $params = [
            ":CDFILIAL" => $branch,
            ":CDLOJA"   => $store
        ];
        
        $idControlProd = $this->connection->fetchAll($sql, $params);
        
        if (empty($idControlProd)) 
            throw new Exception\ParamsException("A tela de controle de produção não está parametrizada para a filial - $branch");

        if (!isset($idControlProd[0]["IDCONTROPROD"]))
            throw new Exception\ParamsException("A tela de controle de produção não está parametrizada para a filial - $branch");
        
        return $idControlProd[0]["IDCONTROPROD"];
    }

    public function getStoresNames($cdFilial) {
        $sql = "
             SELECT DISTINCT CX.CDLOJA, LJ.NMLOJA
               FROM CONFTELACAIXA CT
               JOIN CAIXA CX
                 ON CX.CDFILIAL = CT.CDFILICAIXA
                AND CX.CDCAIXA = CT.CDCAIXA
               JOIN LOJA LJ
                 ON CX.CDLOJA = LJ.CDLOJA
                AND CT.CDFILICAIXA = LJ.CDFILIAL
              WHERE CT.CDFILICAIXA = :CDFILIAL
           ORDER BY CDLOJA
        ";
        
        $params = [
            ':CDFILIAL' => $cdFilial    
        ];
        
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getPOSNames($cdFilial, $cdLoja) {
        $sql = "
             SELECT CDCAIXA, NMCAIXA, IDHABCAIXAVENDA
               FROM CAIXA
              WHERE CDFILIAL = :CDFILIAL
                AND CDLOJA   = :CDLOJA
           ORDER BY CDCAIXA
        ";
        
        $params = [
            ':CDFILIAL' => $cdFilial,
            ':CDLOJA'   => $cdLoja
        ];
        
        return $this->connection->fetchAll($sql, $params);
        
    }
    
    public function getDefaultPOS($cdFilial) {
        $sql = "
             SELECT V.CDCAIXA
               FROM VENDEDOR V
               JOIN PARAVEND P
                 ON P.CDVENDEDOR = V.CDVENDEDOR
              WHERE P.CDFILIAL = :CDFILIAL
        ";
        
        $params = [
            ':CDFILIAL' => $cdFilial
        ];
        
        return $this->connection->fetchAssoc($sql, $params);
        
    }
    
    public function getPosMenus($cdFilial, $cdCaixa) {
        $sql = "
            SELECT NRCONFTELA, DTINIVIGENCIA FROM CONFTELACAIXA
            WHERE CDFILICAIXA = :CDFILIAL
            AND CDCAIXA = :CDCAIXA
            AND DTINIVIGENCIA = (SELECT DTINIVIGENCIA FROM (SELECT DTINIVIGENCIA 
		    					   FROM CONFTELACAIXA 
                                  WHERE SYSDATE >= DTINIVIGENCIA 
					                AND CDFILICAIXA = :CDFILIAL 
					                AND CDCAIXA  = :CDCAIXA
                               ORDER BY DTINIVIGENCIA DESC) WHERE ROWNUM = 1)
            ORDER BY DTINIVIGENCIA DESC
        ";
        
        $params = [
            ':CDFILIAL' => $cdFilial,
            ':CDCAIXA'  => $cdCaixa
        ];
        
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDefaultStoreByBranch($cdFilial) {
        $sql = "
            SELECT C.CDFILIAL, C.CDLOJA, C.CDCAIXA, V.CDVENDEDOR, V.CDOPERADOR
              FROM CAIXA C , VENDEDOR V, PARAVEND PV
             WHERE C.CDCAIXA     = V.CDCAIXA
               AND C.CDFILIAL    = PV.CDFILIAL
               AND PV.CDVENDEDOR = V.CDVENDEDOR
               AND C.CDFILIAL = :CDFILIAL
            ORDER BY CDFILIAL
        ";
        
        $params = [
            ':CDFILIAL' => $cdFilial
        ];
        
        $data = $this->connection->fetchAssoc($sql, $params);
        
        return !empty($data['CDLOJA']) ? $data['CDLOJA'] : "";
    }
    
    
       public function isPosEnabledToAutomaticOrderPrinting ($branch, $store, $cashier) {
        $sql = "
            SELECT IDIMPAUTCUPEXP, IDIMPAUTCUPFOS
              FROM CAIXA
             WHERE CDFILIAL = :CDFILIAL
               AND CDLOJA   = :CDLOJA
               AND CDCAIXA  = :CDCAIXA";
               
        $params = [
             ":CDFILIAL" => $branch,
             ":CDLOJA"   => $store,
             ":CDCAIXA"  => $cashier
        ]; 
        
        $isAutomaticPrint = $this->connection->fetchAssoc($sql, $params);
        if ((empty($isAutomaticPrint["IDIMPAUTCUPEXP"])) && (empty($isAutomaticPrint["IDIMPAUTCUPFOS"])))
            return null;
        
        return $isAutomaticPrint;
            
    }
    
    public function getConftelacaixaCdfilial($cdFilial, $nrConfTela) {
        $sql = "
            SELECT CDFILIAL
              FROM CONFTELACAIXA
             WHERE CDFILICAIXA = :CDFILIAL
               AND NRCONFTELA = :NRCONFTELA
        ";
        
        $params = [
            ':CDFILIAL' => $cdFilial,
            ':NRCONFTELA' => $nrConfTela
        ];
        
        $cdFilial = $this->connection->fetchAll($sql, $params);
        return $cdFilial[0]['CDFILIAL'];
    }
    
    public function getCashierCode($cdFilial, $cdLoja, $cdCaixa) {
        $sql = "
            SELECT CDFILIAL, CDLOJA, CDCAIXA 
                FROM CAIXA
                WHERE CDFILIAL = :CDFILIAL
                AND CDLOJA = :CDLOJA
                AND CDCAIXA = :CDCAIXA
        ";
        
        $params = [
            ':CDFILIAL' => $cdFilial,
            ':CDLOJA'   => $cdLoja,
            ':CDCAIXA'  => $cdCaixa
        ];
        
        return $this->connection->fetchAssoc($sql, $params);
    }
    
}
